pub struct SimplePlugin {
pub load_count: usize,
pub unload_count: usize,
pub activate_count: usize,
pub deactivate_count: usize,
/* private fields */
}Expand description
A basic Plugin implementation useful for testing.
Tracks how many times each lifecycle hook has been called.
Fields
load_count: usizeNumber of times on_load has been called.
unload_count: usizeNumber of times on_unload has been called.
activate_count: usizeNumber of times on_activate has been called.
deactivate_count: usizeNumber of times on_deactivate has been called.
Implementations
Sourceimpl SimplePlugin
impl SimplePlugin
Sourcepub fn new(name: impl Into<String>, version: impl Into<String>) -> Self
pub fn new(name: impl Into<String>, version: impl Into<String>) -> Self
Create a new simple plugin with the given name and version.
Sourcepub fn with_capability(self, cap: PluginCapability) -> Self
pub fn with_capability(self, cap: PluginCapability) -> Self
Add a capability.
Sourcepub fn with_dependency(self, dep: impl Into<String>) -> Self
pub fn with_dependency(self, dep: impl Into<String>) -> Self
Add a dependency.
Set the author.
Sourcepub fn with_description(self, desc: impl Into<String>) -> Self
pub fn with_description(self, desc: impl Into<String>) -> Self
Set the description.